summaryrefslogtreecommitdiffstats
path: root/src/screen.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-16 23:01:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-16 23:01:29 +0000
commit4304e8d9dab8e20513e38e71b0debdf6937b630c (patch)
tree76a86f013a811449a5b5bfbbbb962e7db0bbcc6a /src/screen.h
parentba24506b3bb46312d998468ad3c1a7f28058b2bd (diff)
downloadtdepowersave-4304e8d9dab8e20513e38e71b0debdf6937b630c.tar.gz
tdepowersave-4304e8d9dab8e20513e38e71b0debdf6937b630c.zip
Finish TQt4 port of kpowersave
This enables both Qt3 and Qt4 builds git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kpowersave@1228282 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/screen.h')
-rw-r--r--src/screen.h37
1 files changed, 19 insertions, 18 deletions
diff --git a/src/screen.h b/src/screen.h
index ed6ad17..231dd6d 100644
--- a/src/screen.h
+++ b/src/screen.h
@@ -22,8 +22,8 @@
/* this is needed to avoid typedef clash with X11/Xmd.h (X11/Xproto.h)
*/
-#ifndef QT_CLEAN_NAMESPACE
-#define QT_CLEAN_NAMESPACE
+#ifndef TQT_CLEAN_NAMESPACE
+#define TQT_CLEAN_NAMESPACE
#endif
// KDE Header
@@ -32,11 +32,11 @@
#include <klocale.h>
// QT Header
-#include <qstring.h>
-#include <qwidget.h>
-//#include <qvector.h>
-#include <qtimer.h>
-#include <qevent.h>
+#include <tqstring.h>
+#include <tqwidget.h>
+//#include <tqvector.h>
+#include <tqtimer.h>
+#include <tqevent.h>
// X11 Header
#include <X11/X.h>
@@ -53,9 +53,10 @@
* \author Danny Kukawka, <dkukawka@suse.de>, <danny.kukawka@web.de>
* \date 2004 - 2006
*/
-class screen : public QWidget
+class screen : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
private:
@@ -96,13 +97,13 @@ private:
*/
int SCREENSAVER_STATUS;
- //! QTimer - interval
+ //! TQTimer - interval
/*! This is the interval to poll the Xscreensaver. The value is 58 sec */
static const int xScreenSaver_timer_interval = 58000;
//! QTimer to check/ping the Xscreensaver
/*! This is the QTimer to ping the Xscreensaver. The ping-interval is defined
* through \ref xScreenSaver_timer_interval . */
- QTimer *check_xscreensaver_timer;
+ TQTimer *check_xscreensaver_timer;
//! the active X-Display
/*! Here we store a pointer to the active X-Display of KDE or GNOME */
@@ -132,9 +133,9 @@ public:
//! to check if \ref check_xscreensaver_timer is active
/*!
* This boolean contains information about QTimer \ref check_xscreensaver_timer .
* \li true: if the QTtimer is running
* \li false: if the QTimer isn't active/ isn't in use
*/
bool check_xscreensaver_timer_runs;
//! info about DPMS on the machine
@@ -157,7 +158,7 @@ public:
//! lock the screen
bool lockScreen();
//! lock the screen with a give alias for the lock method
- bool lockScreen( QString );
+ bool lockScreen( TQString );
//! to set DPMS on/off
bool setDPMS( bool );
//! to set the DPMS Timeouts
@@ -166,9 +167,9 @@ public:
bool setScreenSaver( bool );
//! for check the status of the screensaver
- int checkScreenSaverStatus();
+ int checkScreenSavertqStatus();
//! for check the actual status of DPMS on the machine
- int checkDPMSStatus();
+ int checkDPMStqStatus();
//! default constructor
screen();
@@ -96,13 +97,13 @@ private:
/*! This is the interval to poll the Xscreensaver. The value is 58 sec */
static const int xScreenSaver_timer_interval = 58000;
- //! QTimer to check/ping the Xscreensaver
- /*! This is the QTimer to ping the Xscreensaver. The ping-interval is defined
+ //! TQTimer to check/ping the Xscreensaver
+ /*! This is the TQTimer to ping the Xscreensaver. The ping-interval is defined
* through \ref xScreenSaver_timer_interval . */
@@ -132,9 +133,9 @@ public:
//! to check if \ref check_xscreensaver_timer is active
/*!
- * This boolean contains information about QTimer \ref check_xscreensaver_timer .
- * \li true: if the QTtimer is running
- * \li false: if the QTimer isn't active/ isn't in use
+ * This boolean contains information about TQTimer \ref check_xscreensaver_timer .
+ * \li true: if the TQTtimer is running
+ * \li false: if the TQTimer isn't active/ isn't in use
*/
bool check_xscreensaver_timer_runs;